@@ -298,13 +298,9 @@ class BaseHandler(object):
                     try:
                         setattr(self, attr, getattr(self, method)())
                     except Exception as e:
-                        if self.force_error:
-                            raise
                         if not self.error:
                             tb = traceback.format_exc()
                             return self.render_500_error_response(e, tb)
-                if self.force_error:
-                    raise
                 if self.error:
                     return self.render_error_response(self.error[0], self.error[1])
 
@@ -340,7 +336,10 @@ class BaseHandler(object):
             "code": status_code,
             "message": message
         }
-        response = self.render_response(body, status_code)
+        if not self.force_error:
+            response = self.render_response(body, status_code)
+        else:
+            raise Exception(json.dumps(body))
 
         return response
 
